# setup.py
from setuptools import setup, find_packages

setup(
    name="onkitep",
    version="1.0",
    author="TheWhiteCreator",
    author_email="",  # No email provided
    description="An advanced Python library for creating and executing custom functions dynamically.",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/TheWhiteCreator/onkitep",  # Update with your repository URL if needed
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
